@@ -5,7 +5,7 @@ package Data::Scan::Printer;
 
 # ABSTRACT: Example of a printer consumer for Data::Scan
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -25,12 +25,7 @@ extends 'Data::Scan';
 
 
 sub dspp {
-  my $consumer = Data::Scan::Impl::Printer->new(%Option);
-  __PACKAGE__->new(consumer => $consumer)->process(@_);
-  #
-  # We know this consumer has a dsprint method
-  #
-  $consumer->dsprint
+  __PACKAGE__->new(consumer => Data::Scan::Impl::Printer->new(%Option))->process(@_)
 }
 
 
@@ -48,7 +43,7 @@ Data::Scan::Printer - Example of a printer consumer for Data::Scan
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -62,7 +57,7 @@ version 0.005
 
 =head1 DESCRIPTION
 
-Data::Scan::Printer is polluting user's namespace with a dspp() method, showing our Data::Scan can be used to dump an arbitrary structure.
+Data::Scan::Printer is polluting user's namespace with a dspp() method, showing how Data::Scan can be used to dump an arbitrary structure. This is a sort of L<Data::Printer> alternative.
 
 =head1 SUBROUTINES/METHODS
 
